# skan v0.9

This release contains minor API improvements, fixed deprecations from
outdated numba usage, and documentation improvements. Thanks to
[@CsatiZoltan](https://github.com/CsatiZoltan),
[@evan10s](https://github.com/evan10s),
[@theo258](https://github.com/theo258),
[@theodumont](https://github.com/theodumont), and
[@TaekedeHaan](https://github.com/TaekedeHaan) for contributions.
